@@ -5,9 +5,10 @@ Import of guide_bot without visualization
 from ._version import __version__
 
 # Main logic
-from .logic.guide_bot_main import Guide
-from .logic.guide_bot_main import Project
+from .logic.Guide import Guide
+from .logic.Project import Project
 from .logic.runner import RunFromFile
+from .logic.line_of_sight import ElementPoint
 
 # Parameter types and constraint
 from .parameters.instrument_parameters import FixedInstrumentParameter
@@ -16,10 +17,13 @@ from .parameters.instrument_parameters import DependentInstrumentParameter
 from .parameters.constraints import Constraint
 
 # Requirements
-from .requirements.Sample import Sample
-from .requirements.Source import Moderator
-from .requirements.MCPL_source import MCPL_source
-from .requirements.ESS_Butterfly_source import ESS_Butterfly
+from guide_bot.target.BaseTarget import BaseTarget
+from guide_bot.target.Target import Target
+
+# Sources
+from .sources.Simple_source import Moderator
+from .sources.MCPL_source import MCPL_source
+from .sources.ESS_Butterfly_source import ESS_Butterfly
 
 # guide modules
 from .elements.Element_gap import Gap
@@ -28,4 +32,9 @@ from .elements.Element_slit import Slit
 from .elements.Element_straight import Straight
 from .elements.Element_elliptic import Elliptic
 from .elements.Element_curved import Curved
+from .elements.Element_wolter_EH import Wolter_EH
+from .elements.Element_wolter_PH import Wolter_PH
+
+# Visualization
+from .scan_visualization.interfaces import Results
 
