@@ -14,7 +14,7 @@ class ClusterBase:
             path to the configuration file, if None user cluster_config
         """
         if config_path is None:
-            package_path = pathlib.Path(__file__).parent.parent.parent.absolute()
+            package_path = pathlib.Path(__file__).parent.parent.absolute()
             config_path = os.path.join(package_path, "cluster_config")
 
         self.config_path = config_path
