@@ -1,12 +1,11 @@
 from guide_bot.base_elements import guide_elements
-from guide_bot.base_elements import element_group as groups
 from guide_bot.parameters import instrument_parameters as ipars
 
 def length_system(elements, total_length, instrument_parameters):
     """
     System for handling length of each element with given constraints
 
-    A total length from source to sample is given, along with a number of
+    A total length from source to target is given, along with a number of
     elements, each with their own constraints on starting distance from the
     source and length of the element. Some constraints are in the form of a
     fixed starting point or a fixed length, others as a range of allowed
@@ -27,7 +26,7 @@ def length_system(elements, total_length, instrument_parameters):
         The elements describing this guide
 
     total_length : float
-        The distance from source to sample along the guide
+        The distance from source to target along the guide
 
     instrument_parameters : InstrumentParameterContainer
         Parameter container where parameters can be added for optimization
@@ -37,11 +36,11 @@ def length_system(elements, total_length, instrument_parameters):
     if not isinstance(elements, list):
         elements = [elements]
 
-    # Add the change point for guide to sample at the end at the sample location
-    par = ipars.FixedInstrumentParameter("sample_cp", total_length)
+    # Add the change point for guide to target at the end at the target location
+    par = ipars.FixedInstrumentParameter("target_cp", total_length)
     par.set_category("length_system")
     instrument_parameters.add_parameter(par)
-    elements[-1].next_start_point_parameter = par  # last element told sample pos
+    elements[-1].next_start_point_parameter = par  # last element told target pos
 
     # Use fixed lengths to find additional fixed points which simplifies the problem
     propagate_fixed_lengths_to_start_points(elements, total_length)
@@ -407,7 +406,7 @@ def propagate_fixed_lengths_to_start_points(elements, total_length):
         The elements describing this guide
 
     total_length : float
-        The distance from source to sample along the guide
+        The distance from source to target along the guide
     """
     # Set start point of guide to 0.0
     elements[0].start_point = ipars.FixedInstrumentParameter("start_point", 0.0)
