@@ -2,7 +2,7 @@ import unittest
 import unittest.mock
 
 from guide_bot.requirements.requirement_parameters import Parameters
-from guide_bot.requirements.requirement_parameters import InputConfigurationIterator
+from guide_bot.requirements.input_configuration_iterator import InputConfigurationIterator
 
 
 def setup_simple():
